﻿using Windows.Foundation;
using Windows.Foundation.Metadata;
using Windows.Graphics.Display;
using Windows.UI.ViewManagement;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;

namespace TestProject
{
    /// <summary>
    /// 메인 페이지
    /// </summary>
    public sealed partial class MainPage : Page
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainPage()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainPage()
        {
            InitializeComponent();

            #region 윈도우 크기를 설정한다.

            double width  = 800d;
            double height = 600d;

            double dpi = (double)DisplayInformation.GetForCurrentView().LogicalDpi;

            ApplicationView.PreferredLaunchWindowingMode = ApplicationViewWindowingMode.PreferredLaunchViewSize;

            Size windowSize = new Size(width * 96d / dpi, height * 96d / dpi);

            ApplicationView.PreferredLaunchViewSize = windowSize;

            Window.Current.Activate();

            ApplicationView.GetForCurrentView().TryResizeView(windowSize);

            #endregion
            #region 윈도우 제목을 설정한다.

            ApplicationView.GetForCurrentView().Title = "Application 클래스 : FocusVisualKind 속성을 사용해 포커스 사각형 모양 변경하기";

            #endregion

            if
            (
                ApiInformation.IsApiContractPresent("Windows.Foundation.UniversalApiContract", 6) &&
                Application.Current.FocusVisualKind == FocusVisualKind.Reveal
            )
            {
                this.revealRadioButton.IsChecked = true;
            }
            else
            {
                this.highVisibilityRadioButton.IsChecked = true;
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region High Visibility 라디오 버튼 체크시 처리하기 - highVisibilityRadioButton_Checked(sender, e)

        /// <summary>
        /// High Visibility 라디오 버튼 체크시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void highVisibilityRadioButton_Checked(object sender, RoutedEventArgs e)
        {
            Application.Current.FocusVisualKind = FocusVisualKind.HighVisibility;
        }

        #endregion
        #region Reveal 라디오 버튼 체크시 처리하기 - revealRadioButton_Checked(sender, e)

        /// <summary>
        /// Reveal 라디오 버튼 체크시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void revealRadioButton_Checked(object sender, RoutedEventArgs e)
        {
            if(ApiInformation.IsApiContractPresent("Windows.Foundation.UniversalApiContract", 6))
            {
                Application.Current.FocusVisualKind = FocusVisualKind.Reveal;
            }
        }

        #endregion
    }
}